psql.pgpass

Match ~/.pgpass passwords to db specs.

Match ~/.pgpass passwords to db specs.
raw docstring

default-pgpass-fileclj

(default-pgpass-file)
(default-pgpass-file env os-name user-home)

Get PGPASSFILE or the default password file for the platform.

Get PGPASSFILE or the default password file for the platform.
sourceraw docstring

parse-pgpass-lineclj

(parse-pgpass-line s)

The .pgpass file uses this line format: hostname:port:database:username:password. Return a field map {:pg-hostname "*" ...}, or nil for an ignored line.

The .pgpass file uses this line format: hostname:port:database:username:password.
Return a field map {:pg-hostname "*" ...}, or nil for an ignored line.
sourceraw docstring

pgpass-lookupclj

(pgpass-lookup spec)
(pgpass-lookup spec passfile)

Look up a password from db spec {:host ... :port ... :dbname ... :user ...}.

Look up a password from db spec {:host ... :port ... :dbname ... :user ...}.
sourceraw docstring

pgpass-matches?clj

(pgpass-matches? {:keys [host port dbname user]}
                 {:keys [pg-hostname pg-port pg-database pg-username
                         pg-password]})

(filter (partial pgpass-matches? spec) pgpass-lines)

(filter (partial pgpass-matches? spec) pgpass-lines)
sourceraw docstring

read-pgpassclj

(read-pgpass)
(read-pgpass passfile)

Read the resolved or explicit password file. Parse valid records into maps.

Read the resolved or explicit password file. Parse valid records into maps.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries