psql.core

Allow using PostgreSQL from Clojure as effortlessly as possible by reading connection parameter defaults from PostgreSQL environment variables PGDATABASE, PGHOST, PGPORT, PGUSER and by reading password from ~/.pgpass if available.

Allow using PostgreSQL from Clojure as effortlessly as possible by reading connection parameter defaults from
PostgreSQL environment variables PGDATABASE, PGHOST, PGPORT, PGUSER and by reading password from ~/.pgpass if available.
raw docstring

psql.pgpass

Logic for matching passwords ~/.pgpass passwords to db specs.

Logic for matching passwords ~/.pgpass passwords to db specs.
raw docstring

psql.pool

Hikari based connection pool

Hikari based connection pool
raw docstring

psql.spatial

Constructors for PostGIS geometry objects.

(require '[psql.spatial :as st])

Constructors for PostGIS geometry objects.

(require '[psql.spatial :as st])
raw docstring

psql.types

Extend next.jdbc's SettableParameter and ReadableColumn protocols so that PostGIS geometry, PGobject (json/jsonb), SQL arrays and inet values move between Clojure data and PostgreSQL without manual wrapping.

Extend next.jdbc's SettableParameter and ReadableColumn protocols so that
PostGIS geometry, PGobject (json/jsonb), SQL arrays and inet values move
between Clojure data and PostgreSQL without manual wrapping.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries