psql.pgpass

Logic for matching passwords ~/.pgpass passwords to db specs.

Logic for matching passwords ~/.pgpass passwords to db specs.
raw docstring

default-pgpass-fileclj

(default-pgpass-file)
(default-pgpass-file env os-name user-home)

Resolve PGPASSFILE or the platform's default password file.

Resolve PGPASSFILE or the platform's default password file.
sourceraw docstring

parse-pgpass-lineclj

(parse-pgpass-line s)

The .pgpass file has lines of format: hostname:port:database:username:password. Return a map of fields {:pg-hostname "*" ...}, or nil for an ignored line.

The .pgpass file has lines of format: hostname:port:database:username:password.
Return a map of fields {:pg-hostname "*" ...}, or nil for an ignored line.
sourceraw docstring

pgpass-lookupclj

(pgpass-lookup spec)
(pgpass-lookup spec passfile)

Look up a password based on db spec {:host ... :port ... :dbname ... :user ...}.

Look up a password based on db spec {:host ... :port ... :dbname ... :user ...}.
sourceraw docstring

pgpass-matches?clj

(pgpass-matches? {:keys [host port dbname user]}
                 {:keys [pg-hostname pg-port pg-database pg-username
                         pg-password]})

(filter (partial pgpass-matches? spec) pgpass-lines)

(filter (partial pgpass-matches? spec) pgpass-lines)
sourceraw docstring

read-pgpassclj

(read-pgpass)
(read-pgpass passfile)

Read the resolved or explicit password file and parse valid records into maps.

Read the resolved or explicit password file and parse valid records into maps.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries