Extend next.jdbc's SettableParameter and ReadableColumn protocols so that PostGIS geometry, PGobject (json/jsonb), SQL arrays and inet values move between Clojure data and PostgreSQL without manual wrapping.
Extend next.jdbc's SettableParameter and ReadableColumn protocols so that PostGIS geometry, PGobject (json/jsonb), SQL arrays and inet values move between Clojure data and PostgreSQL without manual wrapping.
(pmd md i)Convert one column of ParameterMetaData to a map.
Convert one column of ParameterMetaData to a map.
(read-pg-array s)Arrays are of the form {1,2,3}.
Arrays are of the form {1,2,3}.
(read-pg-vector s)oidvector, int2vector, etc. are space separated lists.
oidvector, int2vector, etc. are space separated lists.
Convert a returned PGobject to a Clojure value.
Convert a returned PGobject to a Clojure value.
(rsmd md i)Convert one column of ResultSetMetaData to a map.
Convert one column of ResultSetMetaData to a map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |